pub enum AddSubcommand {
Crate(AddCrateCommand),
InternalDep(AddInternalDepCommand),
}Variants
Crate(AddCrateCommand)
Add a new crate to the workspace
InternalDep(AddInternalDepCommand)
Add an internal dependency (target-crate depends on dep-crate)
Implementations
Sourceimpl AddSubcommand
Next, in your AddSubcommand::run method (where the lifetime error appeared),
simply clone the crate_name to pass as owned String to the helper.
impl AddSubcommand
Next, in your AddSubcommand::run method (where the lifetime error appeared),
simply clone the crate_name to pass as owned String to the helper.
pub async fn run(&self) -> Result<(), WorkspaceError>