Enum RegisterSubcommand

pub enum RegisterSubcommand {
    CrateFiles {
        crate_name: PathBuf,
        skip_git_check: bool,
    },
    AllFiles {
        workspace_path: PathBuf,
        skip_git_check: bool,
    },
    Internal {
        prefix_crate: PathBuf,
        new_crate: PathBuf,
        workspace_path: Option<PathBuf>,
        skip_git_check: bool,
    },
}
Register subcommand for naming files, adding crate references, etc.

Variants



CrateFiles

Ensure all source files in a single crate are “registered” (that is, it calls CrateHandle::ensure_all_source_files_are_registered()).

Fields

crate_name: PathBuf

Path (or name) of the crate directory

skip_git_check: bool

If true, skip checking for Git cleanliness



AllFiles

Ensure all source files in every crate of a workspace are “registered.” (Calls Workspace::ensure_all_source_files_are_registered().)

Fields

workspace_path: PathBuf

Path to the workspace root

skip_git_check: bool

If true, skip checking for Git cleanliness



Internal

Register a new internal crate in a “prefix group” crate by adding a [dependencies] entry in the prefix crate’s Cargo.toml plus a pub use new_crate_name::*; line in src/lib.rs.

Fields

prefix_crate: PathBuf

Path (or name) of the prefix crate

new_crate: PathBuf

Path (or name) of the new crate to add

workspace_path: Option<PathBuf>

Optionally specify the workspace root path (defaults to current directory if omitted).

skip_git_check: bool

If true, skip checking for Git cleanliness

Implementations