pub struct AnalyzeWorkspaceCommand { /* private fields */ }Expand description
For analyzing an entire workspace, we define a similar struct but without a crate name. We just need to know (optionally) the workspace path and skip-git-check.
Implementations
Sourceimpl AnalyzeWorkspaceCommand
impl AnalyzeWorkspaceCommand
Sourcepub fn workspace_path(&self) -> &Option<PathBuf>
pub fn workspace_path(&self) -> &Option<PathBuf>
If provided, we use this as the workspace root
Sourcepub fn skip_git_check(&self) -> &bool
pub fn skip_git_check(&self) -> &bool
Skip Git clean check
Sourceimpl AnalyzeWorkspaceCommand
impl AnalyzeWorkspaceCommand
pub async fn run(&self) -> Result<(), WorkspaceError>